""" {{ service_name }}Service Class Definition. """


# Imports
from fastapi import Depends


class {{ service_name }}Service:

    def __init__(self) -> None:
        ...
    
    # define methods here to use for the service.