""" {{ model_name }} Tortoise Model """

# Imports
from tortoise.models import Model
from tortoise import fields

class {{ model_name }}(Model):
    ...

    def __str__(self):
        ...
    
    def __repr__(self):
        ...